package
Version:
v0.0.0-...-ee71810
Opens a new window with list of versions in this module.
Published: Dec 29, 2025
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type TestDao struct {
DB dbv1.IDB `autowrite:""`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.